#[repr(u16)]pub enum SystemError {
Show 16 variants
Unknown = 0,
BadOrderId = 1,
Io = 2,
BadInputLength = 3,
BadApiIndex = 4,
BadTrieKey = 5,
SnakeCapacityIsZero = 6,
BadOffset = 7,
SnakeBadLength = 8,
GeneFromHexErr = 9,
GeneIdMismatch = 10,
DeadSet = 11,
SendTimeOut = 12,
PondNoEmptySlotWasFound = 13,
TrieKeyEmpty = 14,
BadCoords = 15,
}Variants
Unknown = 0
BadOrderId = 1
Io = 2
BadInputLength = 3
BadApiIndex = 4
BadTrieKey = 5
SnakeCapacityIsZero = 6
BadOffset = 7
SnakeBadLength = 8
GeneFromHexErr = 9
could count parse gene from hex string
GeneIdMismatch = 10
this may happen if id of gene on the disk is not the correct id
DeadSet = 11
using set for deleting aka seting alive to false without .del(…)
SendTimeOut = 12
PondNoEmptySlotWasFound = 13
TrieKeyEmpty = 14
BadCoords = 15